<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['upgrade_filemanager'] = [
    [
        'version' => '0',
        'library' => 'filemanager/migrations/filemanager_upgrade_0',
    ],
];
